@@ -4,13 +4,12 @@
 import os
 import torch
 
-from turbo_broccoli.environment import register_pytorch_module_type
+from common import from_json, to_json  # Must be before turbo_broccoli imports
 
-from common import from_json, to_json
+from turbo_broccoli.environment import register_pytorch_module_type
 
 
 class _TestModule(torch.nn.Module):
-
     module: torch.nn.Module
 
     def __init__(self):
