@@ -10,13 +10,13 @@ import numpy as np
 from common import from_json, to_json
 from numpy.testing import assert_array_equal
 from scipy import sparse
+from sklearn.base import BaseEstimator
 from sklearn.calibration import *
 from sklearn.cluster import *
 from sklearn.compose import *
 from sklearn.covariance import *
 from sklearn.cross_decomposition import *
 from sklearn.datasets import *
-from sklearn.datasets import load_digits, make_sparse_coded_signal
 from sklearn.decomposition import *
 from sklearn.discriminant_analysis import *
 from sklearn.ensemble import *
@@ -33,6 +33,7 @@ from sklearn.kernel_ridge import *
 from sklearn.linear_model import *
 from sklearn.manifold import *
 from sklearn.metrics import *
+from sklearn.metrics.pairwise import pairwise_kernels
 from sklearn.mixture import *
 from sklearn.model_selection import *
 from sklearn.multiclass import *
@@ -46,7 +47,6 @@ from sklearn.random_projection import *
 from sklearn.semi_supervised import *
 from sklearn.svm import *
 from sklearn.tree import *
-from sklearn.metrics.pairwise import pairwise_kernels
 
 
 def _to_json_and_back(obj: BaseEstimator) -> BaseEstimator:
@@ -84,8 +84,8 @@ def _fit_score_test(
     obj: BaseEstimator,
     x_train: np.ndarray,
     x_test: np.ndarray,
-    y_train: Optional[np.ndarray] = None,
-    y_test: Optional[np.ndarray] = None,
+    y_train: np.ndarray | None = None,
+    y_test: np.ndarray | None = None,
 ) -> Tuple[BaseEstimator, BaseEstimator]:
     obj = obj.fit(x_train, y_train)
     obj2 = _to_json_and_back(obj)
@@ -389,13 +389,19 @@ def test_dictionarylearning():
     """
     https://scikit-learn.org/stable/modules/generated/sklearn.decomposition.DictionaryLearning.html
     """
-    x, _, _ = make_sparse_coded_signal(
+    x1, _, _ = make_sparse_coded_signal(
         n_samples=100,
         n_components=15,
         n_features=20,
         n_nonzero_coefs=10,
         random_state=42,
-        data_transposed=False,
+    )
+    x2, _, _ = make_sparse_coded_signal(
+        n_samples=100,
+        n_components=15,
+        n_features=20,
+        n_nonzero_coefs=10,
+        random_state=43,
     )
     e = DictionaryLearning(
         n_components=15,
@@ -404,7 +410,7 @@ def test_dictionarylearning():
         random_state=42,
         max_iter=10,
     )
-    _fit_transform_x_test(e, x, x)
+    _fit_transform_x_test(e, x1, x2)
 
 
 def test_fastica():
@@ -441,6 +447,29 @@ def test_minibatchdictionarylearning():
     """
     https://scikit-learn.org/stable/modules/generated/sklearn.decomposition.MiniBatchDictionaryLearning.html
     """
+    x1, _, _ = make_sparse_coded_signal(
+        n_samples=30,
+        n_components=15,
+        n_features=20,
+        n_nonzero_coefs=10,
+        random_state=42,
+    )
+    x2, _, _ = make_sparse_coded_signal(
+        n_samples=30,
+        n_components=15,
+        n_features=20,
+        n_nonzero_coefs=10,
+        random_state=43,
+    )
+    dict_learner = MiniBatchDictionaryLearning(
+        n_components=15,
+        batch_size=3,
+        transform_algorithm="lasso_lars",
+        transform_alpha=0.1,
+        max_iter=20,
+        random_state=42,
+    )
+    _fit_transform_x_test(dict_learner, x1, x2)
 
 
 def test_minibatchnmf():
@@ -453,7 +482,6 @@ def test_minibatchnmf():
     #     n_features=20,
     #     n_nonzero_coefs=10,
     #     random_state=42,
-    #     data_transposed=False,
     # )
     # e = MiniBatchDictionaryLearning(
     #     n_components=15,
@@ -530,54 +558,54 @@ def test_latentdirichletallocation():
     """
     https://scikit-learn.org/stable/modules/generated/sklearn.decomposition.LatentDirichletAllocation.html
     """
-    # x, _ = make_multilabel_classification(random_state=0)
-    # e = LatentDirichletAllocation(n_components=5, random_state=0)
-    # _fit_transform_x_test(e, x, x[-2:])
+    x, _ = make_multilabel_classification(random_state=0)
+    e = LatentDirichletAllocation(n_components=5, random_state=0)
+    _fit_transform_x_test(e, x, x[-2:])
 
 
 def test_randomforestclassifier():
     """
     https://scikit-learn.org/stable/modules/generated/sklearn.ensemble.RandomForestClassifier.html
     """
-    # x, y = make_classification(
-    #     n_samples=1000,
-    #     n_features=4,
-    #     n_informative=2,
-    #     n_redundant=0,
-    #     random_state=0,
-    #     shuffle=False,
-    # )
-    # z = [[0, 0, 0, 0]]
-    # e = RandomForestClassifier(max_depth=2, random_state=0)
-    # e.fit(x, y)
-    # e2 = _to_json_and_back(e)
-    # assert_array_equal(e.predict(z), e2.predict(z))
+    x, y = make_classification(
+        n_samples=1000,
+        n_features=4,
+        n_informative=2,
+        n_redundant=0,
+        random_state=0,
+        shuffle=False,
+    )
+    z = [[0, 0, 0, 0]]
+    e = RandomForestClassifier(max_depth=2, random_state=0)
+    e.fit(x, y)
+    e2 = _to_json_and_back(e)
+    assert_array_equal(e.predict(z), e2.predict(z))
 
 
 def test_randomforestregressor():
     """
     https://scikit-learn.org/stable/modules/generated/sklearn.ensemble.RandomForestRegressor.html
     """
-    # x, y = make_classification(
-    #     n_samples=1000,
-    #     n_features=4,
-    #     n_informative=2,
-    #     n_redundant=0,
-    #     random_state=0,
-    #     shuffle=False,
-    # )
-    # z = [[0, 0, 0, 0]]
-    # e = RandomForestRegressor(max_depth=2, random_state=0)
-    # e.fit(x, y)
-    # e2 = _to_json_and_back(e)
-    # assert_array_equal(e.predict(z), e2.predict(z))
+    x, y = make_classification(
+        n_samples=1000,
+        n_features=4,
+        n_informative=2,
+        n_redundant=0,
+        random_state=0,
+        shuffle=False,
+    )
+    z = [[0, 0, 0, 0]]
+    e = RandomForestRegressor(max_depth=2, random_state=0)
+    e.fit(x, y)
+    e2 = _to_json_and_back(e)
+    assert_array_equal(e.predict(z), e2.predict(z))
 
 
 def test_randomtreesembedding():
     """
     https://scikit-learn.org/stable/modules/generated/sklearn.ensemble.RandomTreesEmbedding.html
     """
-    # x = [[0,0], [1,0], [0,1], [-1,0], [0,-1]]
+    # x = [[0, 0], [1, 0], [0, 1], [-1, 0], [0, -1]]
     # e = RandomTreesEmbedding(n_estimators=5, random_state=0, max_depth=1)
     # _fit_transform_x_test(e, x, x)
 
@@ -586,20 +614,20 @@ def test_extratreesclassifier():
     """
     https://scikit-learn.org/stable/modules/generated/sklearn.ensemble.ExtraTreesClassifier.html
     """
-    # x, y = make_classification(n_features=4, random_state=0)
-    # z = [[0, 0, 0, 0]]
-    # e = ExtraTreesClassifier(n_estimators=100, random_state=0)
-    # _fit_predict_x_y_z_test(e, x, y, z)
+    x, y = make_classification(n_features=4, random_state=0)
+    z = [[0, 0, 0, 0]]
+    e = ExtraTreesClassifier(n_estimators=100, random_state=0)
+    _fit_predict_x_y_z_test(e, x, y, z)
 
 
 def test_extratreesregressor():
     """
     https://scikit-learn.org/stable/modules/generated/sklearn.ensemble.ExtraTreesRegressor.html
     """
-    # x, y = load_diabetes(return_X_y=True)
-    # x_train, x_test, y_train, y_test = train_test_split(x, y, random_state=0)
-    # e = ExtraTreesRegressor(n_estimators=100, random_state=0)
-    # _fit_score_test(e, x_train, x_test, y_train, y_test)
+    x, y = load_diabetes(return_X_y=True)
+    x_train, x_test, y_train, y_test = train_test_split(x, y, random_state=0)
+    e = ExtraTreesRegressor(n_estimators=100, random_state=0)
+    _fit_score_test(e, x_train, x_test, y_train, y_test)
 
 
 def test_baggingclassifier():
@@ -640,8 +668,8 @@ def test_isolationforest():
     """
     https://scikit-learn.org/stable/modules/generated/sklearn.ensemble.IsolationForest.html
     """
-    # x = [[-1.1], [0.3], [0.5], [100]]
-    # _fit_predict_x_y_test(IsolationForest(random_state=0), x, x)
+    x = [[-1.1], [0.3], [0.5], [100]]
+    _fit_predict_x_z_test(IsolationForest(random_state=0), x, x)
 
 
 def test_gradientboostingclassifier():
@@ -672,36 +700,36 @@ def test_adaboostclassifier():
     """
     https://scikit-learn.org/stable/modules/generated/sklearn.ensemble.AdaBoostClassifier.html
     """
-    # x, y = make_classification(
-    #     n_samples=1000,
-    #     n_features=4,
-    #     n_informative=2,
-    #     n_redundant=0,
-    #     random_state=0,
-    #     shuffle=False,
-    # )
-    # z = [[0, 0, 0, 0]]
-    # e = AdaBoostClassifier(n_estimators=100, random_state=0)
-    # e, e2 = _fit_predict_x_y_z_test(e, x, y, z)
-    # assert_array_equal(e.score(x, y), e2.score(x, y))
+    x, y = make_classification(
+        n_samples=1000,
+        n_features=4,
+        n_informative=2,
+        n_redundant=0,
+        random_state=0,
+        shuffle=False,
+    )
+    z = [[0, 0, 0, 0]]
+    e = AdaBoostClassifier(n_estimators=100, random_state=0)
+    e, e2 = _fit_predict_x_y_z_test(e, x, y, z)
+    assert_array_equal(e.score(x, y), e2.score(x, y))
 
 
 def test_adaboostregressor():
     """
     https://scikit-learn.org/stable/modules/generated/sklearn.ensemble.AdaBoostRegressor.html
     """
-    # x, y = make_classification(
-    #     n_samples=1000,
-    #     n_features=4,
-    #     n_informative=2,
-    #     n_redundant=0,
-    #     random_state=0,
-    #     shuffle=False,
-    # )
-    # z = [[0, 0, 0, 0]]
-    # e = AdaBoostRegressor(random_state=0, n_estimators=100)
-    # e, e2 = _fit_predict_x_y_z_test(e, x, y, z)
-    # assert_array_equal(e.score(x, y), e2.score(x, y))
+    x, y = make_classification(
+        n_samples=1000,
+        n_features=4,
+        n_informative=2,
+        n_redundant=0,
+        random_state=0,
+        shuffle=False,
+    )
+    z = [[0, 0, 0, 0]]
+    e = AdaBoostRegressor(random_state=0, n_estimators=100)
+    e, e2 = _fit_predict_x_y_z_test(e, x, y, z)
+    assert_array_equal(e.score(x, y), e2.score(x, y))
 
 
 def test_histgradientboostingclassifier():
@@ -777,7 +805,7 @@ def test_ardregression():
     https://scikit-learn.org/stable/modules/generated/sklearn.linear_model.ARDRegression.html
     """
     x, y, z = [[0, 0], [1, 1], [2, 2]], [0, 1, 2], [[1, 1]]
-    _fit_predict_x_y_z_test(ARDRegression(n_iter=10), x, y, z)
+    _fit_predict_x_y_z_test(ARDRegression(max_iter=10), x, y, z)
 
 
 def test_bayesianridge():
@@ -929,7 +957,7 @@ def test_quantileregressor():
     n_samples, n_features = 10, 2
     rng = np.random.RandomState(0)
     x, y = rng.randn(n_samples, n_features), rng.randn(n_samples)
-    e = QuantileRegressor(quantile=0.8, solver="interior-point")
+    e = QuantileRegressor(quantile=0.8, solver="highs")
     _fit_score_test(e, x, x, y, y)
 
 
@@ -1227,11 +1255,11 @@ def test_kerneldensity():
     """
     https://scikit-learn.org/stable/modules/generated/sklearn.neighbors.KernelDensity.html
     """
-    # rng = np.random.RandomState(42)
-    # x = rng.random_sample((100, 3))
-    # e = KernelDensity(kernel="gaussian", bandwidth=0.5).fit(x)
-    # e2 = _to_json_and_back(e)
-    # assert_array_equal(e.score_samples(x[:3]), e2.score_samples(x[:3]))
+    rng = np.random.RandomState(42)
+    x = rng.random_sample((100, 3))
+    e = KernelDensity(kernel="gaussian", bandwidth=0.5).fit(x)
+    e2 = _to_json_and_back(e)
+    assert_array_equal(e.score_samples(x[:3]), e2.score_samples(x[:3]))
 
 
 def test_localoutlierfactor():
@@ -1247,9 +1275,12 @@ def test_neighborhoodcomponentsanalysis():
     """
     https://scikit-learn.org/stable/modules/generated/sklearn.neighbors.NeighborhoodComponentsAnalysis.html
     """
-    # x, y = load_iris(return_X_y=True)
-    # e = NeighborhoodComponentsAnalysis(random_state=42)
-    # _fit_transform_x_y_test(e, x, x, y, y)
+    x, y = load_iris(return_X_y=True)
+    e1 = NeighborhoodComponentsAnalysis(random_state=42)
+    x_tr1 = e1.fit_transform(x, y)
+    e2 = _to_json_and_back(e1)
+    x_tr2 = e2.transform(x)
+    assert_array_equal(x_tr1, x_tr2)
 
 
 def test_bernoullirbm():
@@ -1264,24 +1295,24 @@ def test_mlpclassifier():
     """
     https://scikit-learn.org/stable/modules/generated/sklearn.neural_network.MLPClassifier.html
     """
-    # x, y = make_classification(n_samples=100, random_state=1)
-    # x_train, x_test, y_train, y_test = train_test_split(
-    #     x, y, stratify=y, random_state=1
-    # )
-    # e = MLPClassifier(random_state=1, max_iter=10)
-    # _fit_score_test(e, x_train, x_test, y_train, y_test)
+    x, y = make_classification(n_samples=100, random_state=1)
+    x_train, x_test, y_train, y_test = train_test_split(
+        x, y, stratify=y, random_state=1
+    )
+    e = MLPClassifier(random_state=1, max_iter=10)
+    _fit_score_test(e, x_train, x_test, y_train, y_test)
 
 
 def test_mlpregressor():
     """
     https://scikit-learn.org/stable/modules/generated/sklearn.neural_network.MLPRegressor.html
     """
-    # x, y = make_classification(n_samples=100, random_state=1)
-    # x_train, x_test, y_train, y_test = train_test_split(
-    #     x, y, stratify=y, random_state=1
-    # )
-    # e = MLPRegressor(random_state=1, max_iter=10)
-    # _fit_score_test(e, x_train, x_test, y_train, y_test)
+    x, y = make_classification(n_samples=100, random_state=1)
+    x_train, x_test, y_train, y_test = train_test_split(
+        x, y, stratify=y, random_state=1
+    )
+    e = MLPRegressor(random_state=1, max_iter=10)
+    _fit_score_test(e, x_train, x_test, y_train, y_test)
 
 
 def test_binarizer():
@@ -1412,18 +1443,18 @@ def test_sparserandomprojection():
     """
     https://scikit-learn.org/stable/modules/generated/sklearn.random_projection.SparseRandomProjection.html
     """
-    # rng = np.random.RandomState(42)
-    # x = rng.rand(25, 3000)
-    # _fit_transform_x_test(SparseRandomProjection(random_state=rng), x, x)
+    rng = np.random.RandomState(42)
+    x = rng.rand(25, 3000)
+    _fit_transform_x_test(SparseRandomProjection(random_state=rng), x, x)
 
 
 def test_gaussianrandomprojection():
     """
     https://scikit-learn.org/stable/modules/generated/sklearn.random_projection.GaussianRandomProjection.html
     """
-    # rng = np.random.RandomState(42)
-    # x = rng.rand(25, 3000)
-    # _fit_transform_x_test(GaussianRandomProjection(random_state=rng), x, x)
+    rng = np.random.RandomState(42)
+    x = rng.rand(25, 3000)
+    _fit_transform_x_test(GaussianRandomProjection(random_state=rng), x, x)
 
 
 def test_labelpropagation():
@@ -1457,7 +1488,7 @@ def test_linearsvc():
     https://scikit-learn.org/stable/modules/generated/sklearn.svm.LinearSVC.html
     """
     x, y = make_classification(n_features=4, random_state=0)
-    e = LinearSVC(random_state=0, tol=1e-5)
+    e = LinearSVC(random_state=0, tol=1e-5, dual=True)
     _fit_score_test(e, x, x, y, y)
 
 
@@ -1466,7 +1497,7 @@ def test_linearsvr():
     https://scikit-learn.org/stable/modules/generated/sklearn.svm.LinearSVR.html
     """
     x, y = make_classification(n_features=4, random_state=0)
-    e = LinearSVR(random_state=0, tol=1e-5)
+    e = LinearSVR(random_state=0, tol=1e-5, dual=True)
     _fit_score_test(e, x, x, y, y)
 
 
@@ -1520,39 +1551,39 @@ def test_decisiontreeclassifier():
     """
     https://scikit-learn.org/stable/modules/generated/sklearn.tree.DecisionTreeClassifier.html
     """
-    # iris = load_iris()
-    # x, y = iris.data, iris.target
-    # e = DecisionTreeClassifier(random_state=0)
-    # _fit_score_test(e, x, x, y, y)
+    iris = load_iris()
+    x, y = iris.data, iris.target
+    e = DecisionTreeClassifier(random_state=0)
+    _fit_score_test(e, x, x, y, y)
 
 
 def test_decisiontreeregressor():
     """
     https://scikit-learn.org/stable/modules/generated/sklearn.tree.DecisionTreeRegressor.html
     """
-    # x, y = load_diabetes(return_X_y=True)
-    # e = DecisionTreeRegressor(random_state=0)
-    # _fit_score_test(e, x, x, y, y)
+    x, y = load_diabetes(return_X_y=True)
+    e = DecisionTreeRegressor(random_state=0)
+    _fit_score_test(e, x, x, y, y)
 
 
 def test_extratreeclassifier():
     """
     https://scikit-learn.org/stable/modules/generated/sklearn.tree.ExtraTreeClassifier.html
     """
-    # x, y = load_iris(return_X_y=True)
-    # x_train, x_test, y_train, y_test = train_test_split(x, y, random_state=0)
-    # e = ExtraTreeClassifier(random_state=0)
-    # _fit_score_test(e, x_train, x_test, y_train, y_test)
+    x, y = load_iris(return_X_y=True)
+    x_train, x_test, y_train, y_test = train_test_split(x, y, random_state=0)
+    e = ExtraTreeClassifier(random_state=0)
+    _fit_score_test(e, x_train, x_test, y_train, y_test)
 
 
 def test_extratreeregressor():
     """
     https://scikit-learn.org/stable/modules/generated/sklearn.tree.ExtraTreeRegressor.html
     """
-    # x, y = load_iris(return_X_y=True)
-    # x_train, x_test, y_train, y_test = train_test_split(x, y, random_state=0)
-    # e = ExtraTreeRegressor(random_state=0)
-    # _fit_score_test(e, x_train, x_test, y_train, y_test)
+    x, y = load_iris(return_X_y=True)
+    x_train, x_test, y_train, y_test = train_test_split(x, y, random_state=0)
+    e = ExtraTreeRegressor(random_state=0)
+    _fit_score_test(e, x_train, x_test, y_train, y_test)
 
 
 def test_lineardiscriminantanalysis():
