@@ -14,11 +14,18 @@ from turbo_broccoli.environment import (
     set_max_nbytes,
     set_pandas_format,
 )
-from turbo_broccoli.guard import guarded_call, produces_document
+from turbo_broccoli.guard import (
+    GuardedBlockHandler,
+    guarded_call,
+    produces_document,
+)
+from turbo_broccoli.native import load, save
 from turbo_broccoli.turbo_broccoli import (
     TurboBroccoliDecoder,
     TurboBroccoliEncoder,
     from_json,
+    load_json,
+    save_json,
     to_json,
 )
 
