@@ -1,11 +1,14 @@
 """bytes (de)serialization utilities."""
 __docformat__ = "google"
 
-from typing import Any, Optional
-
 from base64 import b64decode, b64encode
+from typing import Any
 
-from turbo_broccoli.environment import is_nodecode
+from turbo_broccoli.utils import (
+    DeserializationError,
+    TypeNotSupported,
+    raise_if_nodecode,
+)
 
 
 def _bytes_from_json_v1(dct: dict) -> bytes:
@@ -15,21 +18,20 @@ def _bytes_from_json_v1(dct: dict) -> bytes:
     return b64decode(dct["data"])
 
 
-def from_json(dct: dict) -> Optional[bytes]:
+def from_json(dct: dict) -> bytes | None:
     """
     Deserializes a dict into a bytes object. See `to_json` for the
     specification `dct` is expected to follow. In particular, note that `dct`
     must contain the key `__bytes__`.
     """
-    if is_nodecode("bytes"):
-        return None
+    raise_if_nodecode("bytes")
     DECODERS = {
         1: _bytes_from_json_v1,
     }
     try:
         return DECODERS[dct["__bytes__"]["__version__"]](dct["__bytes__"])
     except KeyError as exc:
-        raise TypeError("Not a valid bytes document") from exc
+        raise DeserializationError() from exc
 
 
 def to_json(obj: Any) -> dict:
@@ -53,4 +55,4 @@ def to_json(obj: Any) -> dict:
                 "data": b64encode(obj).decode("ascii"),
             },
         }
-    raise TypeError("Not a valid bytes object")
+    raise TypeNotSupported()
