@@ -5,7 +5,11 @@ from typing import Any
 
 from turbo_broccoli.environment import (
     get_registered_dataclass_type,
-    is_nodecode,
+)
+from turbo_broccoli.utils import (
+    DeserializationError,
+    TypeNotSupported,
+    raise_if_nodecode,
 )
 
 
@@ -14,8 +18,6 @@ def _json_to_dataclass_v2(dct: dict) -> Any:
     Converts a JSON document following the v2 specification to a dataclass
     object.
     """
-    if is_nodecode("dataclass." + dct["class"]):
-        return None
     return get_registered_dataclass_type(dct["class"])(**dct["data"])
 
 
@@ -25,15 +27,17 @@ def from_json(dct: dict) -> Any:
     specification `dct` is expected to follow, and
     `turbo_broccoli.environment.register_dataclass_type`.
     """
+    raise_if_nodecode("dataclass")
     DECODERS = {
         2: _json_to_dataclass_v2,
     }
     try:
+        raise_if_nodecode("dataclass." + dct["__dataclass__"]["class"])
         return DECODERS[dct["__dataclass__"]["__version__"]](
             dct["__dataclass__"]
         )
     except KeyError as exc:
-        raise TypeError("Not a valid dataclass document") from exc
+        raise DeserializationError() from exc
 
 
 def to_json(obj: Any) -> dict:
@@ -59,4 +63,4 @@ def to_json(obj: Any) -> dict:
                 "data": obj.__dict__,
             },
         }
-    raise TypeError("Not a supported type")
+    raise TypeNotSupported()
