@@ -2,14 +2,19 @@
 __docformat__ = "google"
 
 from functools import partial
-from typing import Any, Callable, List, Tuple
+from typing import Any, Callable, Tuple
 from uuid import uuid4
 
 from tensorflow import keras
+
 from turbo_broccoli.environment import (
     get_artifact_path,
     get_keras_format,
-    is_nodecode,
+)
+from turbo_broccoli.utils import (
+    DeserializationError,
+    TypeNotSupported,
+    raise_if_nodecode,
 )
 
 KERAS_LAYERS = {
@@ -221,6 +226,7 @@ def _json_to_model(dct: dict) -> Any:
     DECODERS = {
         1: _json_to_model_v1,
         2: _json_to_model_v2,
+        3: _json_to_model_v3,
     }
     return DECODERS[dct["__version__"]](dct)
 
@@ -252,6 +258,16 @@ def _json_to_model_v2(dct: dict) -> Any:
     )
 
 
+def _json_to_model_v3(dct: dict) -> Any:
+    """
+    Converts a JSON document to a keras model object following the v2
+    specification.
+    """
+    if "model" in dct:
+        return _json_to_model_v1(dct)
+    return keras.models.load_model(get_artifact_path() / dct["id"])
+
+
 def _json_to_optimizer(dct: dict) -> Any:
     """Converts a JSON document to a serializable keras object."""
     DECODERS = {
@@ -294,10 +310,10 @@ def _model_to_json(model: keras.Model) -> dict:
             "weights": model.weights,
         }
     name = str(uuid4())
-    model.save(get_artifact_path() / (name + "." + fmt), save_format=fmt)
+    model.save(get_artifact_path() / name, save_format=fmt)
     return {
         "__type__": "model",
-        "__version__": 2,
+        "__version__": 3,
         "format": fmt,
         "id": name,
     }
@@ -309,6 +325,7 @@ def from_json(dct: dict) -> Any:
     specification `dct` is expected to follow. In particular, note that `dct`
     must contain the key `__keras__`.
     """
+    raise_if_nodecode("keras")
     DECODERS = {
         "model": _json_to_model,  # must be first!
         "layer": _json_to_layer,
@@ -318,11 +335,10 @@ def from_json(dct: dict) -> Any:
     }
     try:
         type_name = dct["__keras__"]["__type__"]
-        if is_nodecode("keras." + type_name):
-            return None
+        raise_if_nodecode("keras." + type_name)
         return DECODERS[type_name](dct["__keras__"])
     except KeyError as exc:
-        raise TypeError("Not a valid Keras document") from exc
+        raise DeserializationError() from exc
 
 
 def to_json(obj: Any) -> dict:
@@ -340,7 +356,7 @@ def to_json(obj: Any) -> dict:
     depends on the precise type of `obj`. Most keras object will simply be
     serialized using `keras.utils.serialize_keras_object`. Here are the exceptions:
 
-    * `keras.Model` (the model must have weights). If `TB_KERAS_FORMAT` is
+    - `keras.Model` (the model must have weights). If `TB_KERAS_FORMAT` is
       `json`, the document will look like
 
             {
@@ -360,14 +376,14 @@ def to_json(obj: Any) -> dict:
             {
                 "__keras__": {
                     "__type__": "model",
-                    "__version__": 2,
+                    "__version__": 3,
                     "format": <str>,
                     "id": <UUID4 str>
                 }
             }
 
     """
-    ENCODERS: List[Tuple[type, Callable[[Any], dict]]] = [
+    ENCODERS: list[Tuple[type, Callable[[Any], dict]]] = [
         (keras.Model, _model_to_json),  # must be first
         (
             keras.metrics.Metric,
@@ -383,4 +399,4 @@ def to_json(obj: Any) -> dict:
     for t, f in ENCODERS:
         if isinstance(obj, t):
             return {"__keras__": f(obj)}
-    raise TypeError("Not a supported Keras type")
+    raise TypeNotSupported()
