@@ -6,7 +6,8 @@ Todo:
 """
 __docformat__ = "google"
 
-from typing import Any, Callable, List, Tuple
+import pickle
+from typing import Any, Callable, Tuple
 from uuid import uuid4
 
 import numpy as np
@@ -25,7 +26,11 @@ except ModuleNotFoundError:
 from turbo_broccoli.environment import (
     get_artifact_path,
     get_max_nbytes,
-    is_nodecode,
+)
+from turbo_broccoli.utils import (
+    DeserializationError,
+    TypeNotSupported,
+    raise_if_nodecode,
 )
 
 
@@ -127,6 +132,27 @@ def _json_to_number_v2(dct: dict) -> np.number:
     return np.frombuffer(dct["value"], dtype=dct["dtype"])[0]
 
 
+def _json_to_random_state(dct: dict) -> np.number:
+    """
+    Converts a JSON document to a numpy random state. See `to_json` for the
+    specification `dct` is expected to follow. Note that the key `__numpy__`
+    should not be present.
+    """
+    DECODERS = {
+        1: _json_to_random_state_v1,
+    }
+    return DECODERS[dct["__version__"]](dct)
+
+
+def _json_to_random_state_v1(dct: dict) -> np.number:
+    """
+    Converts a JSON document to a numpy random state following the v1
+    specification.
+    """
+    with open(get_artifact_path() / dct["data"], mode="rb") as fp:
+        return pickle.load(fp)
+
+
 def _dtype_to_json(d: np.dtype) -> dict:
     """Serializes a `numpy` array."""
     return {
@@ -198,24 +224,38 @@ def _number_to_json(num: np.number) -> dict:
     }
 
 
+def _random_state_to_json(obj: np.random.RandomState) -> dict:
+    """Pickles a numpy random state"""
+    name, protocol = str(uuid4()), pickle.HIGHEST_PROTOCOL
+    with open(get_artifact_path() / name, mode="wb") as fp:
+        pickle.dump(obj, fp, protocol=protocol)
+    return {
+        "__type__": "random_state",
+        "__version__": 1,
+        "data": name,
+        "protocol": protocol,
+    }
+
+
 def from_json(dct: dict) -> Any:
     """
     Deserializes a dict into a numpy object. See `to_json` for the
     specification `dct` is expected to follow. In particular, note that `dct`
     must contain the key `__numpy__`.
     """
+    raise_if_nodecode("numpy")
     DECODERS = {
         "ndarray": _json_to_ndarray,
         "number": _json_to_number,
         "dtype": _json_to_dtype,
+        "random_state": _json_to_random_state,
     }
     try:
         type_name = dct["__numpy__"]["__type__"]
-        if is_nodecode("numpy." + type_name):
-            return None
+        raise_if_nodecode("numpy." + type_name)
         return DECODERS[type_name](dct["__numpy__"])
     except KeyError as exc:
-        raise TypeError("Not a valid numpy document") from exc
+        raise DeserializationError() from exc
 
 
 def to_json(obj: Any) -> dict:
@@ -232,7 +272,7 @@ def to_json(obj: Any) -> dict:
     where the `{...}` dict contains the actual data, and whose structure
     depends on the precise type of `obj`.
 
-    * `numpy.ndarray`: An array is processed differently depending on its size
+    - `numpy.ndarray`: An array is processed differently depending on its size
       and on the `TB_MAX_NBYTES` environment variable. If the array is
       small, i.e. `arr.nbytes <= TB_MAX_NBYTES`, then it is directly
       stored in the resulting JSON document as
@@ -277,7 +317,7 @@ def to_json(obj: Any) -> dict:
       to store an array of 1000 `float64`s, and `TB_ARTIFACT_PATH` is `./`.
       `TB_ARTIFACT_PATH` must point to an existing directory.
 
-    * `numpy.number`:
+    - `numpy.number`:
 
             {
                 "__numpy__": {
@@ -290,7 +330,7 @@ def to_json(obj: Any) -> dict:
 
         where the `dtype` document follows the specification below.
 
-    * `numpy.dtype`:
+    - `numpy.dtype`:
 
             {
                 "__numpy__": {
@@ -300,13 +340,28 @@ def to_json(obj: Any) -> dict:
                 }
             }
 
+    - `numpy.random.RandomState`:
+
+            {
+                "__numpy__": {
+                    "__type__": "random_state",
+                    "__version__": 1,
+                    "dtype": <uuid4>,
+                    "protocol": <int>
+                }
+            }
+
+      where the UUID4 points to a pickle file artefact, and the protocol is the
+      pickle protocol.
+
     """
-    ENCODERS: List[Tuple[type, Callable[[Any], dict]]] = [
+    ENCODERS: list[Tuple[type, Callable[[Any], dict]]] = [
         (np.ndarray, _ndarray_to_json),
         (np.number, _number_to_json),
         (np.dtype, _dtype_to_json),
+        (np.random.RandomState, _random_state_to_json),
     ]
     for t, f in ENCODERS:
         if isinstance(obj, t):
             return {"__numpy__": f(obj)}
-    raise TypeError("Not a supported numpy type")
+    raise TypeNotSupported()
